| Type: | Package |
| Title: | Neutrosophic Analysis of Incomplete Block Designs |
| Version: | 0.1.1 |
| Maintainer: | Vinaykumar L.N. <vinaymandya123@gmail.com> |
| Description: | Provides methods for neutrosophic analysis of variance (NANOVA) and neutrosophic analysis of covariance (NANCOVA) for interval-valued data arising from incomplete block design experiments. The package supports balanced incomplete block designs (BIBDs), partially balanced incomplete block designs (PBIBDs), and lattice designs. Functions are included for treatment comparisons, least significant difference (LSD) tests, and interval-based statistical inference under neutrosophic environments. |
| License: | GPL-2 | GPL-3 [expanded from: GPL (≥ 2)] |
| Encoding: | UTF-8 |
| Depends: | R (≥ 4.0.0) |
| Imports: | MASS, stats |
| RoxygenNote: | 7.3.3 |
| NeedsCompilation: | no |
| Packaged: | 2026-06-01 04:29:26 UTC; admin |
| Author: | Neethu R.S. [aut, ctb], Cini Varghese [aut, ctb], Mohd Harun [aut, ctb], Anindita Datta [aut, ctb], Vinaykumar L.N. [aut, cre] |
| Repository: | CRAN |
| Date/Publication: | 2026-06-05 14:50:06 UTC |
Neutrosophic ANCOVA for Incomplete Block Designs
Description
Performs neutrosophic analysis of covariance for incomplete block designs using interval-valued responses and covariates.
Usage
IBDnsANCOVA(
Lower_y,
Upper_y,
Lower_z,
Upper_z,
design,
alpha = 0.05,
verbose = FALSE
)
Arguments
Lower_y |
Matrix of lower interval responses. |
Upper_y |
Matrix of upper interval responses. |
Lower_z |
Matrix of lower interval covariates. |
Upper_z |
Matrix of upper interval covariates. |
design |
Incomplete block design matrix. |
alpha |
Significance level for LSD test and F-test (default = 0.05). |
verbose |
Logical. If TRUE, prints the neutrosophic ANCOVA table, significance codes, LSD interval and pairwise treatment comparisons. Default = FALSE. |
Details
The rows of the response and design arrays represent blocks, while the columns represent treatment allocations within blocks.
Value
A list containing:
STAR_NANCOVA : Neutrosophic ANCOVA table.
LSD : Neutrosophic LSD interval.
Comparison : Pairwise treatment comparison table.
Examples
Lower_y<-matrix(c(
46.46436719,49.56056768,47.21541951,
47.41402083,51.24762662,50.95734839,
50.7492564,51.250892,50.01772519,
51.72202304,53.83285904,54.53288749,
53.71983091,55.3957797,53.85646279,
55.29951886,57.48888886,56.81959243,
56.01454397,57.64266115,56.15643552
),nrow=7,byrow=TRUE)
Upper_y<-matrix(c(
49.53563281,52.43943232,52.78458049,
52.58597917,54.75237338,53.04265161,
53.2507436,56.749108,55.98227481,
54.27797696,58.16714096,59.46711251,
56.28016909,60.6042203,58.14353721,
58.70048114,60.51111114,59.18040757,
59.98545603,62.35733885,61.84356448
),nrow=7,byrow=TRUE)
Lower_z<-matrix(c(
87.6024962,49.87728481,21.20537996,
74.19109283,70.90050743,69.79918837,
118.3567216,84.52944492,87.2387685,
116.5444728,127.5038727,122.3890764,
104.4945972,117.9310944,126.206537,
101.9435439,91.18240208,81.56378309,
92.28882349,86.13485988,83.04950126
),nrow=7,byrow=TRUE)
Upper_z<-matrix(c(
90.3975038,60.12271519,32.79462004,
81.80890717,73.09949257,72.20081163,
127.6432784,97.47055508,102.7612315,
131.4555272,136.4961273,135.6109236,
119.5054028,122.0689056,133.793463,
116.0564561,102.8175979,96.43621691,
99.71117651,93.86514012,92.95049874
),nrow=7,byrow=TRUE)
design<-matrix(c(
1,2,4,
2,3,5,
3,4,6,
4,5,7,
5,6,1,
6,7,2,
7,1,3
),nrow=7,byrow=TRUE)
IBDnsANCOVA(
Lower_y = Lower_y,
Upper_y = Upper_y,
Lower_z = Lower_z,
Upper_z = Upper_z,
design = design,
verbose = TRUE
)
Neutrosophic ANOVA for Incomplete Block Designs
Description
Performs neutrosophic analysis of variance for incomplete block designs using interval-valued observations.
Usage
IBDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = FALSE)
Arguments
Lower_y |
Matrix of lower interval responses. |
Upper_y |
Matrix of upper interval responses. |
design |
Incomplete block design matrix. |
alpha |
Significance level for LSD test and F-test (default = 0.05). |
verbose |
Logical. If TRUE, prints the neutrosophic ANOVA table, LSD interval, significance codes and pairwise treatment comparisons. Default = FALSE. |
Details
The rows of the response and design arrays represent blocks, while the columns represent treatment allocations within blocks.
Value
A list containing:
STAR_NANOVA : Neutrosophic ANOVA table.
LSD : Neutrosophic LSD interval.
Comparison : Pairwise treatment comparison table.
Examples
Lower_y <- matrix(c(
46.46436719,49.56056768,47.21541951,
47.41402083,51.24762662,50.95734839,
50.74925640,51.25089200,50.01772519,
51.72202304,53.83285904,54.53288749,
53.71983091,55.39577970,53.85646279,
55.29951886,57.48888886,56.81959243,
56.01454397,57.64266115,56.15643552
), nrow = 7, byrow = TRUE)
Upper_y <- matrix(c(
49.53563281,52.43943232,52.78458049,
52.58597917,54.75237338,53.04265161,
53.25074360,56.74910800,55.98227481,
54.27797696,58.16714096,59.46711251,
56.28016909,60.60422030,58.14353721,
58.70048114,60.51111114,59.18040757,
59.98545603,62.35733885,61.84356448
), nrow = 7, byrow = TRUE)
design <- matrix(c(
1,2,4,
2,3,5,
3,4,6,
4,5,7,
5,6,1,
6,7,2,
7,1,3
), nrow = 7, byrow = TRUE)
IBDnsANOVA(
Lower_y,
Upper_y,
design,
verbose = TRUE
)
Neutrosophic ANCOVA for Lattice Designs
Description
Performs neutrosophic analysis of covariance for lattice designs using interval-valued responses and covariates.
Usage
LDnsANCOVA(
Lower_y,
Upper_y,
Lower_z,
Upper_z,
design,
alpha = 0.05,
verbose = FALSE
)
Arguments
Lower_y |
Matrix of lower interval responses. |
Upper_y |
Matrix of upper interval responses. |
Lower_z |
Matrix of lower interval covariates. |
Upper_z |
Matrix of upper interval covariates. |
design |
Lattice design matrix. |
alpha |
Significance level for LSD test and F-test (default = 0.05). |
verbose |
Logical. If TRUE, prints the neutrosophic ANCOVA table, significance codes, LSD interval and pairwise treatment comparisons. Default = FALSE. |
Details
The rows of the response and design arrays represent blocks, while the columns represent treatment allocations within blocks.
Value
A list containing:
STAR_NANCOVA : Neutrosophic ANCOVA table.
LSD : Neutrosophic LSD interval.
Comparison : Pairwise treatment comparison table.
Examples
#' @examples
Lower_y <- matrix(c(
86.81,81.44,89.83,
76.14,72.77,72.93,
92.17,58.56,70.48,
111.43,78.95,56.87,
84.71,74.19,98.10,
78.91,90.49,87.52,
99.76,80.10,94.54,
62.05,86.81,63.06,
67.52,70.05,68.24
), nrow=9, byrow=TRUE)
Upper_y <- matrix(c(
89.19,88.56,94.17,
79.86,79.23,79.07,
95.83,65.44,79.52,
118.57,85.05,63.13,
89.29,77.81,105.90,
85.09,99.51,92.48,
104.24,87.90,99.46,
65.95,91.19,70.94,
72.48,79.95,75.76
), nrow=9, byrow=TRUE)
Lower_z <- matrix(c(
27.04,24.47,20.28,
32.31,37.02,23.16,
12.58,8.35,22.37,
7.31,20.02,25.12,
9.93,33.58,12.50,
17.74,37.01,24.99,
22.28,4.65,22.52,
21.71,18.47,20.41,
35.65,17.27,23.22
), nrow=9, byrow=TRUE)
Upper_z <- matrix(c(
36.96,27.53,26.72,
37.69,40.98,26.84,
17.42,15.65,32.03,
16.69,29.78,28.28,
16.07,36.42,21.50,
22.26,40.99,30.01,
25.72,13.35,30.08,
25.49,27.53,29.19,
44.35,24.73,30.98
), nrow=9, byrow=TRUE)
design <- matrix(c(
1,2,3,
7,9,8,
6,4,5,
1,7,4,
8,5,2,
3,6,9,
1,8,6,
4,2,9,
3,5,7
), nrow=9, byrow=TRUE)
LDnsANCOVA(
Lower_y = Lower_y,
Upper_y = Upper_y,
Lower_z = Lower_z,
Upper_z = Upper_z,
design = design
)
Neutrosophic ANOVA for Lattice Designs
Description
Performs neutrosophic analysis of variance for lattice designs using interval-valued observations.
Usage
LDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = FALSE)
Arguments
Lower_y |
Matrix of lower interval responses. |
Upper_y |
Matrix of upper interval responses. |
design |
Lattice design matrix. |
alpha |
Significance level for LSD test and F-test (default = 0.05). |
verbose |
Logical. If TRUE, prints the neutrosophic ANOVA table, significance codes, LSD interval and pairwise treatment comparisons. Default = FALSE. |
Details
The rows of the response and design arrays represent blocks, while the columns represent treatment allocations within blocks.
Value
A list containing:
STAR_NANOVA : Neutrosophic ANOVA table.
LSD : Neutrosophic LSD interval.
Comparison : Pairwise treatment comparison table.
Examples
Lower_y <- matrix(c(
86.81,81.44,89.83,
76.14,72.77,72.93,
92.17,58.56,70.48,
111.43,78.95,56.87,
84.71,74.19,98.10,
78.91,90.49,87.52,
99.76,80.10,94.54,
62.05,86.81,63.06,
67.52,70.05,68.24
), nrow=9, byrow=TRUE)
Upper_y <- matrix(c(
89.19,88.56,94.17,
79.86,79.23,79.07,
95.83,65.44,79.52,
118.57,85.05,63.13,
89.29,77.81,105.90,
85.09,99.51,92.48,
104.24,87.90,99.46,
65.95,91.19,70.94,
72.48,79.95,75.76
), nrow=9, byrow=TRUE)
design <- matrix(c(
1,2,3,
7,9,8,
6,4,5,
1,7,4,
8,5,2,
3,6,9,
1,8,6,
4,2,9,
3,5,7
), nrow=9, byrow=TRUE)
LDnsANOVA(
Lower_y,
Upper_y,
design,
verbose = TRUE
)